/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qcamera.sip"
#include <qcamera.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"

#line 50 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qcameradevice.sip"
#include <qcameradevice.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qcameradevice.sip"
#include <qcameradevice.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtMultimedia/qmediacapturesession.sip"
#include <qmediacapturesession.h>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtMultimedia/sipQtMultimediaQCamera.cpp"


class sipQCamera : public ::QCamera
{
public:
    sipQCamera(const ::QCameraDevice&, ::QObject*);
    sipQCamera(::QCameraDevice::Position, ::QObject*);
    sipQCamera(::QObject*);
    virtual ~sipQCamera();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQCamera(const sipQCamera &);
    sipQCamera &operator = (const sipQCamera &);

    char sipPyMethods[7];
};

sipQCamera::sipQCamera(const ::QCameraDevice& a0, ::QObject*a1): ::QCamera(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQCamera::sipQCamera(::QCameraDevice::Position a0, ::QObject*a1): ::QCamera(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQCamera::sipQCamera(::QObject*a0): ::QCamera(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQCamera::~sipQCamera()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQCamera::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QCamera);

    return ::QCamera::metaObject();
}

int sipQCamera::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QCamera::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QCamera, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQCamera::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QCamera, _clname, &sipCpp) ? sipCpp : ::QCamera::qt_metacast(_clname));
}

bool sipQCamera::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QCamera::event(a0);

    extern bool sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQCamera::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QCamera::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_4(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQCamera::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QCamera::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_3(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCamera::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QCamera::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCamera::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QCamera::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_1(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCamera::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QCamera::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_0(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCamera::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QCamera::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_0(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QCamera_isAvailable, "isAvailable(self) -> bool");

extern "C" {static PyObject *meth_QCamera_isAvailable(PyObject *, PyObject *);}
static PyObject *meth_QCamera_isAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAvailable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_isAvailable, doc_QCamera_isAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_isActive, "isActive(self) -> bool");

extern "C" {static PyObject *meth_QCamera_isActive(PyObject *, PyObject *);}
static PyObject *meth_QCamera_isActive(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isActive();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_isActive, doc_QCamera_isActive);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_captureSession, "captureSession(self) -> QMediaCaptureSession|None");

extern "C" {static PyObject *meth_QCamera_captureSession(PyObject *, PyObject *);}
static PyObject *meth_QCamera_captureSession(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QMediaCaptureSession*sipRes;

            sipRes = sipCpp->captureSession();

            return sipConvertFromType(sipRes, sipType_QMediaCaptureSession, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_captureSession, doc_QCamera_captureSession);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_cameraDevice, "cameraDevice(self) -> QCameraDevice");

extern "C" {static PyObject *meth_QCamera_cameraDevice(PyObject *, PyObject *);}
static PyObject *meth_QCamera_cameraDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCameraDevice*sipRes;

            sipRes = new ::QCameraDevice(sipCpp->cameraDevice());

            return sipConvertFromNewType(sipRes, sipType_QCameraDevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_cameraDevice, doc_QCamera_cameraDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setCameraDevice, "setCameraDevice(self, cameraDevice: QCameraDevice)");

extern "C" {static PyObject *meth_QCamera_setCameraDevice(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setCameraDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraDevice* a0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCameraDevice, &a0))
        {
            sipCpp->setCameraDevice(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setCameraDevice, doc_QCamera_setCameraDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_cameraFormat, "cameraFormat(self) -> QCameraFormat");

extern "C" {static PyObject *meth_QCamera_cameraFormat(PyObject *, PyObject *);}
static PyObject *meth_QCamera_cameraFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCameraFormat*sipRes;

            sipRes = new ::QCameraFormat(sipCpp->cameraFormat());

            return sipConvertFromNewType(sipRes, sipType_QCameraFormat, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_cameraFormat, doc_QCamera_cameraFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setCameraFormat, "setCameraFormat(self, format: QCameraFormat)");

extern "C" {static PyObject *meth_QCamera_setCameraFormat(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setCameraFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraFormat* a0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCameraFormat, &a0))
        {
            sipCpp->setCameraFormat(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setCameraFormat, doc_QCamera_setCameraFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_error, "error(self) -> QCamera.Error");

extern "C" {static PyObject *meth_QCamera_error(PyObject *, PyObject *);}
static PyObject *meth_QCamera_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCamera::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCamera_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_error, doc_QCamera_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QCamera_errorString(PyObject *, PyObject *);}
static PyObject *meth_QCamera_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_errorString, doc_QCamera_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_supportedFeatures, "supportedFeatures(self) -> QCamera.Feature");

extern "C" {static PyObject *meth_QCamera_supportedFeatures(PyObject *, PyObject *);}
static PyObject *meth_QCamera_supportedFeatures(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCamera::Features*sipRes;

            sipRes = new ::QCamera::Features(sipCpp->supportedFeatures());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QCamera_Feature, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_supportedFeatures, doc_QCamera_supportedFeatures);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_focusMode, "focusMode(self) -> QCamera.FocusMode");

extern "C" {static PyObject *meth_QCamera_focusMode(PyObject *, PyObject *);}
static PyObject *meth_QCamera_focusMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCamera::FocusMode sipRes;

            sipRes = sipCpp->focusMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCamera_FocusMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_focusMode, doc_QCamera_focusMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setFocusMode, "setFocusMode(self, mode: QCamera.FocusMode)");

extern "C" {static PyObject *meth_QCamera_setFocusMode(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setFocusMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera::FocusMode a0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCamera_FocusMode, &a0))
        {
            sipCpp->setFocusMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setFocusMode, doc_QCamera_setFocusMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_isFocusModeSupported, "isFocusModeSupported(self, mode: QCamera.FocusMode) -> bool");

extern "C" {static PyObject *meth_QCamera_isFocusModeSupported(PyObject *, PyObject *);}
static PyObject *meth_QCamera_isFocusModeSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera::FocusMode a0;
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCamera_FocusMode, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isFocusModeSupported(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_isFocusModeSupported, doc_QCamera_isFocusModeSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_focusPoint, "focusPoint(self) -> QPointF");

extern "C" {static PyObject *meth_QCamera_focusPoint(PyObject *, PyObject *);}
static PyObject *meth_QCamera_focusPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->focusPoint());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_focusPoint, doc_QCamera_focusPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_customFocusPoint, "customFocusPoint(self) -> QPointF");

extern "C" {static PyObject *meth_QCamera_customFocusPoint(PyObject *, PyObject *);}
static PyObject *meth_QCamera_customFocusPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->customFocusPoint());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_customFocusPoint, doc_QCamera_customFocusPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setCustomFocusPoint, "setCustomFocusPoint(self, point: QPointF)");

extern "C" {static PyObject *meth_QCamera_setCustomFocusPoint(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setCustomFocusPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointF* a0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QCamera, &sipCpp, sipType_QPointF, &a0))
        {
            sipCpp->setCustomFocusPoint(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setCustomFocusPoint, doc_QCamera_setCustomFocusPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setFocusDistance, "setFocusDistance(self, d: float)");

extern "C" {static PyObject *meth_QCamera_setFocusDistance(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setFocusDistance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QCamera, &sipCpp, &a0))
        {
            sipCpp->setFocusDistance(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setFocusDistance, doc_QCamera_setFocusDistance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_focusDistance, "focusDistance(self) -> float");

extern "C" {static PyObject *meth_QCamera_focusDistance(PyObject *, PyObject *);}
static PyObject *meth_QCamera_focusDistance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->focusDistance();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_focusDistance, doc_QCamera_focusDistance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_minimumZoomFactor, "minimumZoomFactor(self) -> float");

extern "C" {static PyObject *meth_QCamera_minimumZoomFactor(PyObject *, PyObject *);}
static PyObject *meth_QCamera_minimumZoomFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->minimumZoomFactor();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_minimumZoomFactor, doc_QCamera_minimumZoomFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_maximumZoomFactor, "maximumZoomFactor(self) -> float");

extern "C" {static PyObject *meth_QCamera_maximumZoomFactor(PyObject *, PyObject *);}
static PyObject *meth_QCamera_maximumZoomFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->maximumZoomFactor();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_maximumZoomFactor, doc_QCamera_maximumZoomFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_zoomFactor, "zoomFactor(self) -> float");

extern "C" {static PyObject *meth_QCamera_zoomFactor(PyObject *, PyObject *);}
static PyObject *meth_QCamera_zoomFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->zoomFactor();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_zoomFactor, doc_QCamera_zoomFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setZoomFactor, "setZoomFactor(self, factor: float)");

extern "C" {static PyObject *meth_QCamera_setZoomFactor(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setZoomFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QCamera, &sipCpp, &a0))
        {
            sipCpp->setZoomFactor(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setZoomFactor, doc_QCamera_setZoomFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_flashMode, "flashMode(self) -> QCamera.FlashMode");

extern "C" {static PyObject *meth_QCamera_flashMode(PyObject *, PyObject *);}
static PyObject *meth_QCamera_flashMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCamera::FlashMode sipRes;

            sipRes = sipCpp->flashMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCamera_FlashMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_flashMode, doc_QCamera_flashMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_isFlashModeSupported, "isFlashModeSupported(self, mode: QCamera.FlashMode) -> bool");

extern "C" {static PyObject *meth_QCamera_isFlashModeSupported(PyObject *, PyObject *);}
static PyObject *meth_QCamera_isFlashModeSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera::FlashMode a0;
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCamera_FlashMode, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isFlashModeSupported(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_isFlashModeSupported, doc_QCamera_isFlashModeSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_isFlashReady, "isFlashReady(self) -> bool");

extern "C" {static PyObject *meth_QCamera_isFlashReady(PyObject *, PyObject *);}
static PyObject *meth_QCamera_isFlashReady(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isFlashReady();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_isFlashReady, doc_QCamera_isFlashReady);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_torchMode, "torchMode(self) -> QCamera.TorchMode");

extern "C" {static PyObject *meth_QCamera_torchMode(PyObject *, PyObject *);}
static PyObject *meth_QCamera_torchMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCamera::TorchMode sipRes;

            sipRes = sipCpp->torchMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCamera_TorchMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_torchMode, doc_QCamera_torchMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_isTorchModeSupported, "isTorchModeSupported(self, mode: QCamera.TorchMode) -> bool");

extern "C" {static PyObject *meth_QCamera_isTorchModeSupported(PyObject *, PyObject *);}
static PyObject *meth_QCamera_isTorchModeSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera::TorchMode a0;
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCamera_TorchMode, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isTorchModeSupported(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_isTorchModeSupported, doc_QCamera_isTorchModeSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_exposureMode, "exposureMode(self) -> QCamera.ExposureMode");

extern "C" {static PyObject *meth_QCamera_exposureMode(PyObject *, PyObject *);}
static PyObject *meth_QCamera_exposureMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCamera::ExposureMode sipRes;

            sipRes = sipCpp->exposureMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCamera_ExposureMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_exposureMode, doc_QCamera_exposureMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_isExposureModeSupported, "isExposureModeSupported(self, mode: QCamera.ExposureMode) -> bool");

extern "C" {static PyObject *meth_QCamera_isExposureModeSupported(PyObject *, PyObject *);}
static PyObject *meth_QCamera_isExposureModeSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera::ExposureMode a0;
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCamera_ExposureMode, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isExposureModeSupported(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_isExposureModeSupported, doc_QCamera_isExposureModeSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_exposureCompensation, "exposureCompensation(self) -> float");

extern "C" {static PyObject *meth_QCamera_exposureCompensation(PyObject *, PyObject *);}
static PyObject *meth_QCamera_exposureCompensation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->exposureCompensation();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_exposureCompensation, doc_QCamera_exposureCompensation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_isoSensitivity, "isoSensitivity(self) -> int");

extern "C" {static PyObject *meth_QCamera_isoSensitivity(PyObject *, PyObject *);}
static PyObject *meth_QCamera_isoSensitivity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->isoSensitivity();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_isoSensitivity, doc_QCamera_isoSensitivity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_manualIsoSensitivity, "manualIsoSensitivity(self) -> int");

extern "C" {static PyObject *meth_QCamera_manualIsoSensitivity(PyObject *, PyObject *);}
static PyObject *meth_QCamera_manualIsoSensitivity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->manualIsoSensitivity();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_manualIsoSensitivity, doc_QCamera_manualIsoSensitivity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_exposureTime, "exposureTime(self) -> float");

extern "C" {static PyObject *meth_QCamera_exposureTime(PyObject *, PyObject *);}
static PyObject *meth_QCamera_exposureTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->exposureTime();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_exposureTime, doc_QCamera_exposureTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_manualExposureTime, "manualExposureTime(self) -> float");

extern "C" {static PyObject *meth_QCamera_manualExposureTime(PyObject *, PyObject *);}
static PyObject *meth_QCamera_manualExposureTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->manualExposureTime();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_manualExposureTime, doc_QCamera_manualExposureTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_minimumIsoSensitivity, "minimumIsoSensitivity(self) -> int");

extern "C" {static PyObject *meth_QCamera_minimumIsoSensitivity(PyObject *, PyObject *);}
static PyObject *meth_QCamera_minimumIsoSensitivity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->minimumIsoSensitivity();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_minimumIsoSensitivity, doc_QCamera_minimumIsoSensitivity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_maximumIsoSensitivity, "maximumIsoSensitivity(self) -> int");

extern "C" {static PyObject *meth_QCamera_maximumIsoSensitivity(PyObject *, PyObject *);}
static PyObject *meth_QCamera_maximumIsoSensitivity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maximumIsoSensitivity();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_maximumIsoSensitivity, doc_QCamera_maximumIsoSensitivity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_minimumExposureTime, "minimumExposureTime(self) -> float");

extern "C" {static PyObject *meth_QCamera_minimumExposureTime(PyObject *, PyObject *);}
static PyObject *meth_QCamera_minimumExposureTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->minimumExposureTime();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_minimumExposureTime, doc_QCamera_minimumExposureTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_maximumExposureTime, "maximumExposureTime(self) -> float");

extern "C" {static PyObject *meth_QCamera_maximumExposureTime(PyObject *, PyObject *);}
static PyObject *meth_QCamera_maximumExposureTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->maximumExposureTime();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_maximumExposureTime, doc_QCamera_maximumExposureTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_whiteBalanceMode, "whiteBalanceMode(self) -> QCamera.WhiteBalanceMode");

extern "C" {static PyObject *meth_QCamera_whiteBalanceMode(PyObject *, PyObject *);}
static PyObject *meth_QCamera_whiteBalanceMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCamera::WhiteBalanceMode sipRes;

            sipRes = sipCpp->whiteBalanceMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCamera_WhiteBalanceMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_whiteBalanceMode, doc_QCamera_whiteBalanceMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_isWhiteBalanceModeSupported, "isWhiteBalanceModeSupported(self, mode: QCamera.WhiteBalanceMode) -> bool");

extern "C" {static PyObject *meth_QCamera_isWhiteBalanceModeSupported(PyObject *, PyObject *);}
static PyObject *meth_QCamera_isWhiteBalanceModeSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera::WhiteBalanceMode a0;
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCamera_WhiteBalanceMode, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isWhiteBalanceModeSupported(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_isWhiteBalanceModeSupported, doc_QCamera_isWhiteBalanceModeSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_colorTemperature, "colorTemperature(self) -> int");

extern "C" {static PyObject *meth_QCamera_colorTemperature(PyObject *, PyObject *);}
static PyObject *meth_QCamera_colorTemperature(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->colorTemperature();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_colorTemperature, doc_QCamera_colorTemperature);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setActive, "setActive(self, active: bool)");

extern "C" {static PyObject *meth_QCamera_setActive(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setActive(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QCamera, &sipCpp, &a0))
        {
            sipCpp->setActive(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setActive, doc_QCamera_setActive);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_start, "start(self)");

extern "C" {static PyObject *meth_QCamera_start(PyObject *, PyObject *);}
static PyObject *meth_QCamera_start(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            sipCpp->start();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_start, doc_QCamera_start);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_stop, "stop(self)");

extern "C" {static PyObject *meth_QCamera_stop(PyObject *, PyObject *);}
static PyObject *meth_QCamera_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_stop, doc_QCamera_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_zoomTo, "zoomTo(self, zoom: float, rate: float)");

extern "C" {static PyObject *meth_QCamera_zoomTo(PyObject *, PyObject *);}
static PyObject *meth_QCamera_zoomTo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        float a1;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bff", &sipSelf, sipType_QCamera, &sipCpp, &a0, &a1))
        {
            sipCpp->zoomTo(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_zoomTo, doc_QCamera_zoomTo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setFlashMode, "setFlashMode(self, mode: QCamera.FlashMode)");

extern "C" {static PyObject *meth_QCamera_setFlashMode(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setFlashMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera::FlashMode a0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCamera_FlashMode, &a0))
        {
            sipCpp->setFlashMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setFlashMode, doc_QCamera_setFlashMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setTorchMode, "setTorchMode(self, mode: QCamera.TorchMode)");

extern "C" {static PyObject *meth_QCamera_setTorchMode(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setTorchMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera::TorchMode a0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCamera_TorchMode, &a0))
        {
            sipCpp->setTorchMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setTorchMode, doc_QCamera_setTorchMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setExposureMode, "setExposureMode(self, mode: QCamera.ExposureMode)");

extern "C" {static PyObject *meth_QCamera_setExposureMode(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setExposureMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera::ExposureMode a0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCamera_ExposureMode, &a0))
        {
            sipCpp->setExposureMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setExposureMode, doc_QCamera_setExposureMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setExposureCompensation, "setExposureCompensation(self, ev: float)");

extern "C" {static PyObject *meth_QCamera_setExposureCompensation(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setExposureCompensation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QCamera, &sipCpp, &a0))
        {
            sipCpp->setExposureCompensation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setExposureCompensation, doc_QCamera_setExposureCompensation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setManualIsoSensitivity, "setManualIsoSensitivity(self, iso: int)");

extern "C" {static PyObject *meth_QCamera_setManualIsoSensitivity(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setManualIsoSensitivity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QCamera, &sipCpp, &a0))
        {
            sipCpp->setManualIsoSensitivity(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setManualIsoSensitivity, doc_QCamera_setManualIsoSensitivity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setAutoIsoSensitivity, "setAutoIsoSensitivity(self)");

extern "C" {static PyObject *meth_QCamera_setAutoIsoSensitivity(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setAutoIsoSensitivity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            sipCpp->setAutoIsoSensitivity();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setAutoIsoSensitivity, doc_QCamera_setAutoIsoSensitivity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setManualExposureTime, "setManualExposureTime(self, seconds: float)");

extern "C" {static PyObject *meth_QCamera_setManualExposureTime(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setManualExposureTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QCamera, &sipCpp, &a0))
        {
            sipCpp->setManualExposureTime(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setManualExposureTime, doc_QCamera_setManualExposureTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setAutoExposureTime, "setAutoExposureTime(self)");

extern "C" {static PyObject *meth_QCamera_setAutoExposureTime(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setAutoExposureTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            sipCpp->setAutoExposureTime();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setAutoExposureTime, doc_QCamera_setAutoExposureTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setWhiteBalanceMode, "setWhiteBalanceMode(self, mode: QCamera.WhiteBalanceMode)");

extern "C" {static PyObject *meth_QCamera_setWhiteBalanceMode(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setWhiteBalanceMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera::WhiteBalanceMode a0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCamera_WhiteBalanceMode, &a0))
        {
            sipCpp->setWhiteBalanceMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setWhiteBalanceMode, doc_QCamera_setWhiteBalanceMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setColorTemperature, "setColorTemperature(self, colorTemperature: int)");

extern "C" {static PyObject *meth_QCamera_setColorTemperature(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setColorTemperature(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QCamera, &sipCpp, &a0))
        {
            sipCpp->setColorTemperature(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setColorTemperature, doc_QCamera_setColorTemperature);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QCamera(void *, const sipTypeDef *);}
static void *cast_QCamera(void *sipCppV, const sipTypeDef *targetType)
{
    ::QCamera *sipCpp = reinterpret_cast< ::QCamera *>(sipCppV);

    if (targetType == sipType_QCamera)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QCamera(void *, int);}
static void release_QCamera(void *sipCppV, int)
{
    ::QCamera *sipCpp = reinterpret_cast< ::QCamera *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QCamera(Py_ssize_t);}
static void *array_QCamera(Py_ssize_t sipNrElem)
{
    return new ::QCamera[sipNrElem];
}


extern "C" {static void array_delete_QCamera(void *);}
static void array_delete_QCamera(void *sipCpp)
{
    delete[] reinterpret_cast< ::QCamera *>(sipCpp);
}


extern "C" {static void dealloc_QCamera(sipSimpleWrapper *);}
static void dealloc_QCamera(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQCamera *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QCamera(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QCamera(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QCamera(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQCamera *sipCpp = SIP_NULLPTR;

    {
        const ::QCameraDevice* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J9|JH", sipType_QCameraDevice, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQCamera(*a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QCameraDevice::Position a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "E|JH", sipType_QCameraDevice_Position, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQCamera(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQCamera(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QCamera[] = {{7, 0, 1}};


static PyMethodDef methods_QCamera[] = {
    {sipName_cameraDevice, meth_QCamera_cameraDevice, METH_VARARGS, doc_QCamera_cameraDevice},
    {sipName_cameraFormat, meth_QCamera_cameraFormat, METH_VARARGS, doc_QCamera_cameraFormat},
    {sipName_captureSession, meth_QCamera_captureSession, METH_VARARGS, doc_QCamera_captureSession},
    {sipName_colorTemperature, meth_QCamera_colorTemperature, METH_VARARGS, doc_QCamera_colorTemperature},
    {sipName_customFocusPoint, meth_QCamera_customFocusPoint, METH_VARARGS, doc_QCamera_customFocusPoint},
    {sipName_error, meth_QCamera_error, METH_VARARGS, doc_QCamera_error},
    {sipName_errorString, meth_QCamera_errorString, METH_VARARGS, doc_QCamera_errorString},
    {sipName_exposureCompensation, meth_QCamera_exposureCompensation, METH_VARARGS, doc_QCamera_exposureCompensation},
    {sipName_exposureMode, meth_QCamera_exposureMode, METH_VARARGS, doc_QCamera_exposureMode},
    {sipName_exposureTime, meth_QCamera_exposureTime, METH_VARARGS, doc_QCamera_exposureTime},
    {sipName_flashMode, meth_QCamera_flashMode, METH_VARARGS, doc_QCamera_flashMode},
    {sipName_focusDistance, meth_QCamera_focusDistance, METH_VARARGS, doc_QCamera_focusDistance},
    {sipName_focusMode, meth_QCamera_focusMode, METH_VARARGS, doc_QCamera_focusMode},
    {sipName_focusPoint, meth_QCamera_focusPoint, METH_VARARGS, doc_QCamera_focusPoint},
    {sipName_isActive, meth_QCamera_isActive, METH_VARARGS, doc_QCamera_isActive},
    {sipName_isAvailable, meth_QCamera_isAvailable, METH_VARARGS, doc_QCamera_isAvailable},
    {sipName_isExposureModeSupported, meth_QCamera_isExposureModeSupported, METH_VARARGS, doc_QCamera_isExposureModeSupported},
    {sipName_isFlashModeSupported, meth_QCamera_isFlashModeSupported, METH_VARARGS, doc_QCamera_isFlashModeSupported},
    {sipName_isFlashReady, meth_QCamera_isFlashReady, METH_VARARGS, doc_QCamera_isFlashReady},
    {sipName_isFocusModeSupported, meth_QCamera_isFocusModeSupported, METH_VARARGS, doc_QCamera_isFocusModeSupported},
    {sipName_isTorchModeSupported, meth_QCamera_isTorchModeSupported, METH_VARARGS, doc_QCamera_isTorchModeSupported},
    {sipName_isWhiteBalanceModeSupported, meth_QCamera_isWhiteBalanceModeSupported, METH_VARARGS, doc_QCamera_isWhiteBalanceModeSupported},
    {sipName_isoSensitivity, meth_QCamera_isoSensitivity, METH_VARARGS, doc_QCamera_isoSensitivity},
    {sipName_manualExposureTime, meth_QCamera_manualExposureTime, METH_VARARGS, doc_QCamera_manualExposureTime},
    {sipName_manualIsoSensitivity, meth_QCamera_manualIsoSensitivity, METH_VARARGS, doc_QCamera_manualIsoSensitivity},
    {sipName_maximumExposureTime, meth_QCamera_maximumExposureTime, METH_VARARGS, doc_QCamera_maximumExposureTime},
    {sipName_maximumIsoSensitivity, meth_QCamera_maximumIsoSensitivity, METH_VARARGS, doc_QCamera_maximumIsoSensitivity},
    {sipName_maximumZoomFactor, meth_QCamera_maximumZoomFactor, METH_VARARGS, doc_QCamera_maximumZoomFactor},
    {sipName_minimumExposureTime, meth_QCamera_minimumExposureTime, METH_VARARGS, doc_QCamera_minimumExposureTime},
    {sipName_minimumIsoSensitivity, meth_QCamera_minimumIsoSensitivity, METH_VARARGS, doc_QCamera_minimumIsoSensitivity},
    {sipName_minimumZoomFactor, meth_QCamera_minimumZoomFactor, METH_VARARGS, doc_QCamera_minimumZoomFactor},
    {sipName_setActive, meth_QCamera_setActive, METH_VARARGS, doc_QCamera_setActive},
    {sipName_setAutoExposureTime, meth_QCamera_setAutoExposureTime, METH_VARARGS, doc_QCamera_setAutoExposureTime},
    {sipName_setAutoIsoSensitivity, meth_QCamera_setAutoIsoSensitivity, METH_VARARGS, doc_QCamera_setAutoIsoSensitivity},
    {sipName_setCameraDevice, meth_QCamera_setCameraDevice, METH_VARARGS, doc_QCamera_setCameraDevice},
    {sipName_setCameraFormat, meth_QCamera_setCameraFormat, METH_VARARGS, doc_QCamera_setCameraFormat},
    {sipName_setColorTemperature, meth_QCamera_setColorTemperature, METH_VARARGS, doc_QCamera_setColorTemperature},
    {sipName_setCustomFocusPoint, meth_QCamera_setCustomFocusPoint, METH_VARARGS, doc_QCamera_setCustomFocusPoint},
    {sipName_setExposureCompensation, meth_QCamera_setExposureCompensation, METH_VARARGS, doc_QCamera_setExposureCompensation},
    {sipName_setExposureMode, meth_QCamera_setExposureMode, METH_VARARGS, doc_QCamera_setExposureMode},
    {sipName_setFlashMode, meth_QCamera_setFlashMode, METH_VARARGS, doc_QCamera_setFlashMode},
    {sipName_setFocusDistance, meth_QCamera_setFocusDistance, METH_VARARGS, doc_QCamera_setFocusDistance},
    {sipName_setFocusMode, meth_QCamera_setFocusMode, METH_VARARGS, doc_QCamera_setFocusMode},
    {sipName_setManualExposureTime, meth_QCamera_setManualExposureTime, METH_VARARGS, doc_QCamera_setManualExposureTime},
    {sipName_setManualIsoSensitivity, meth_QCamera_setManualIsoSensitivity, METH_VARARGS, doc_QCamera_setManualIsoSensitivity},
    {sipName_setTorchMode, meth_QCamera_setTorchMode, METH_VARARGS, doc_QCamera_setTorchMode},
    {sipName_setWhiteBalanceMode, meth_QCamera_setWhiteBalanceMode, METH_VARARGS, doc_QCamera_setWhiteBalanceMode},
    {sipName_setZoomFactor, meth_QCamera_setZoomFactor, METH_VARARGS, doc_QCamera_setZoomFactor},
    {sipName_start, meth_QCamera_start, METH_VARARGS, doc_QCamera_start},
    {sipName_stop, meth_QCamera_stop, METH_VARARGS, doc_QCamera_stop},
    {sipName_supportedFeatures, meth_QCamera_supportedFeatures, METH_VARARGS, doc_QCamera_supportedFeatures},
    {sipName_torchMode, meth_QCamera_torchMode, METH_VARARGS, doc_QCamera_torchMode},
    {sipName_whiteBalanceMode, meth_QCamera_whiteBalanceMode, METH_VARARGS, doc_QCamera_whiteBalanceMode},
    {sipName_zoomFactor, meth_QCamera_zoomFactor, METH_VARARGS, doc_QCamera_zoomFactor},
    {sipName_zoomTo, meth_QCamera_zoomTo, METH_VARARGS, doc_QCamera_zoomTo}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QCamera[] = {
    {sipName_NoError, static_cast<int>(::QCamera::NoError)},
    {sipName_CameraError, static_cast<int>(::QCamera::CameraError)},
    {sipName_ExposureAuto, static_cast<int>(::QCamera::ExposureAuto)},
    {sipName_ExposureManual, static_cast<int>(::QCamera::ExposureManual)},
    {sipName_ExposurePortrait, static_cast<int>(::QCamera::ExposurePortrait)},
    {sipName_ExposureNight, static_cast<int>(::QCamera::ExposureNight)},
    {sipName_ExposureSports, static_cast<int>(::QCamera::ExposureSports)},
    {sipName_ExposureSnow, static_cast<int>(::QCamera::ExposureSnow)},
    {sipName_ExposureBeach, static_cast<int>(::QCamera::ExposureBeach)},
    {sipName_ExposureAction, static_cast<int>(::QCamera::ExposureAction)},
    {sipName_ExposureLandscape, static_cast<int>(::QCamera::ExposureLandscape)},
    {sipName_ExposureNightPortrait, static_cast<int>(::QCamera::ExposureNightPortrait)},
    {sipName_ExposureTheatre, static_cast<int>(::QCamera::ExposureTheatre)},
    {sipName_ExposureSunset, static_cast<int>(::QCamera::ExposureSunset)},
    {sipName_ExposureSteadyPhoto, static_cast<int>(::QCamera::ExposureSteadyPhoto)},
    {sipName_ExposureFireworks, static_cast<int>(::QCamera::ExposureFireworks)},
    {sipName_ExposureParty, static_cast<int>(::QCamera::ExposureParty)},
    {sipName_ExposureCandlelight, static_cast<int>(::QCamera::ExposureCandlelight)},
    {sipName_ExposureBarcode, static_cast<int>(::QCamera::ExposureBarcode)},
    {sipName_ColorTemperature, static_cast<int>(::QCamera::Feature::ColorTemperature)},
    {sipName_ExposureCompensation, static_cast<int>(::QCamera::Feature::ExposureCompensation)},
    {sipName_IsoSensitivity, static_cast<int>(::QCamera::Feature::IsoSensitivity)},
    {sipName_ManualExposureTime, static_cast<int>(::QCamera::Feature::ManualExposureTime)},
    {sipName_CustomFocusPoint, static_cast<int>(::QCamera::Feature::CustomFocusPoint)},
    {sipName_FocusDistance, static_cast<int>(::QCamera::Feature::FocusDistance)},
    {sipName_FlashOff, static_cast<int>(::QCamera::FlashOff)},
    {sipName_FlashOn, static_cast<int>(::QCamera::FlashOn)},
    {sipName_FlashAuto, static_cast<int>(::QCamera::FlashAuto)},
    {sipName_FocusModeAuto, static_cast<int>(::QCamera::FocusModeAuto)},
    {sipName_FocusModeAutoNear, static_cast<int>(::QCamera::FocusModeAutoNear)},
    {sipName_FocusModeAutoFar, static_cast<int>(::QCamera::FocusModeAutoFar)},
    {sipName_FocusModeHyperfocal, static_cast<int>(::QCamera::FocusModeHyperfocal)},
    {sipName_FocusModeInfinity, static_cast<int>(::QCamera::FocusModeInfinity)},
    {sipName_FocusModeManual, static_cast<int>(::QCamera::FocusModeManual)},
    {sipName_TorchOff, static_cast<int>(::QCamera::TorchOff)},
    {sipName_TorchOn, static_cast<int>(::QCamera::TorchOn)},
    {sipName_TorchAuto, static_cast<int>(::QCamera::TorchAuto)},
    {sipName_WhiteBalanceAuto, static_cast<int>(::QCamera::WhiteBalanceAuto)},
    {sipName_WhiteBalanceManual, static_cast<int>(::QCamera::WhiteBalanceManual)},
    {sipName_WhiteBalanceSunlight, static_cast<int>(::QCamera::WhiteBalanceSunlight)},
    {sipName_WhiteBalanceCloudy, static_cast<int>(::QCamera::WhiteBalanceCloudy)},
    {sipName_WhiteBalanceShade, static_cast<int>(::QCamera::WhiteBalanceShade)},
    {sipName_WhiteBalanceTungsten, static_cast<int>(::QCamera::WhiteBalanceTungsten)},
    {sipName_WhiteBalanceFluorescent, static_cast<int>(::QCamera::WhiteBalanceFluorescent)},
    {sipName_WhiteBalanceFlash, static_cast<int>(::QCamera::WhiteBalanceFlash)},
    {sipName_WhiteBalanceSunset, static_cast<int>(::QCamera::WhiteBalanceSunset)},
    {0, 0}
};

PyDoc_STRVAR(doc_QCamera, "\1QCamera(cameraDevice: QCameraDevice, parent: QObject|None = None)\n"
"QCamera(position: QCameraDevice.Position, parent: QObject|None = None)\n"
"QCamera(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QCamera[] = {
    {"manualIsoSensitivityChanged(int)", "\1manualIsoSensitivityChanged(self, a0: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"manualExposureTimeChanged(float)", "\1manualExposureTimeChanged(self, speed: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"focusPointChanged()", "\1focusPointChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"colorTemperatureChanged()", "\1colorTemperatureChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"whiteBalanceModeChanged()", "\1whiteBalanceModeChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"exposureModeChanged()", "\1exposureModeChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"exposureCompensationChanged(float)", "\1exposureCompensationChanged(self, a0: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"isoSensitivityChanged(int)", "\1isoSensitivityChanged(self, a0: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"exposureTimeChanged(float)", "\1exposureTimeChanged(self, speed: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"torchModeChanged()", "\1torchModeChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"flashModeChanged()", "\1flashModeChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"flashReady(bool)", "\1flashReady(self, a0: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"customFocusPointChanged()", "\1customFocusPointChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"focusDistanceChanged(float)", "\1focusDistanceChanged(self, a0: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"maximumZoomFactorChanged(float)", "\1maximumZoomFactorChanged(self, a0: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"minimumZoomFactorChanged(float)", "\1minimumZoomFactorChanged(self, a0: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"zoomFactorChanged(float)", "\1zoomFactorChanged(self, a0: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"focusModeChanged()", "\1focusModeChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"supportedFeaturesChanged()", "\1supportedFeaturesChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"cameraFormatChanged()", "\1cameraFormatChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"cameraDeviceChanged()", "\1cameraDeviceChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"errorOccurred(QCamera::Error,QString)", "\1errorOccurred(self, error: QCamera.Error, errorString: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"errorChanged()", "\1errorChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"activeChanged(bool)", "\1activeChanged(self, a0: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QCamera = {
    &::QCamera::staticMetaObject,
    signals_QCamera,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QCamera = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QCamera,
        SIP_NULLPTR,
        &plugin_QCamera,
    },
    {
        sipNameNr_QCamera,
        {0, 0, 1},
        55, methods_QCamera,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QCamera, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QCamera,
    -1,
    -1,
    supers_QCamera,
    SIP_NULLPTR,
    init_type_QCamera,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QCamera,
    SIP_NULLPTR,
    array_QCamera,
    SIP_NULLPTR,
    release_QCamera,
    cast_QCamera,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QCamera,
    sizeof (::QCamera),
};
